@@ -439,11 +439,18 @@ base_finder (char *path, char **ret)
   }
 }
 
+static gboolean
+on_main_window_focus_in (GtkWidget * widget, GdkEventFocus * event, gpointer data)
+{
+	gtk_window_set_urgency_hint (GTK_WINDOW (main_window), FALSE);
+	return FALSE;
+}
+
 /**
  * Show the "Finished!" dialog, allowing the user to open Nautilus if he wants.
  */
 static void
-show_finished_dialog (void)
+show_finished_dialog (const TrackDetails *track)
 {
   GtkWidget *dialog;
   int result;
@@ -455,18 +462,27 @@ show_finished_dialog (void)
 
   cleanup ();
 
+  char *message;
+  message = g_strdup_printf (_("%s has been copied successfully."), track->album->title);
+
   dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
                                    GTK_DIALOG_DESTROY_WITH_PARENT,
                                    GTK_MESSAGE_INFO,
                                    GTK_BUTTONS_NONE,
-                                   /* TODO: need to have a better message here */
-                                   _("The tracks have been copied successfully."));
+                                   (message));
+
+  g_free (message);
   /* If we eject when finished, eject now, otherwise add a button */
   if (eject_finished) {
     nautilus_burn_drive_eject (drive);
   } else {
     gtk_dialog_add_buttons (GTK_DIALOG (dialog), _("_Eject"), 2, NULL);
   }
+
+  /* Trigger glowing effect after copy */
+  g_signal_connect (G_OBJECT (dialog), "focus-in-event",  G_CALLBACK (on_main_window_focus_in),  NULL);
+  gtk_window_set_urgency_hint (GTK_WINDOW (main_window), TRUE);
+
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
                           GTK_STOCK_OPEN, 1,
                           GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
@@ -501,7 +517,7 @@ on_completion_cb (SjExtractor *extractor, gpointer data)
   }
   
   if (pending == NULL) {
-    show_finished_dialog ();
+    show_finished_dialog (track);
     if (autostart) {
       gtk_main_quit ();
     }
@@ -711,7 +727,11 @@ filepath_parse_pattern (const char* pattern, const TrackDetails *track)
 
     /* If not a % marker, copy and continue */
     if (*p != '%') {
-      g_string_append_unichar (s, g_utf8_get_char (p));
+      if ((*p == ' ') && (strip_chars)) {
+        g_string_append_c (s, '_');
+      } else {
+        g_string_append_unichar (s, g_utf8_get_char (p));
+      }
       p = g_utf8_next_char (p);
       /* Explicit increment as we continue past the increment */
       continue;
