@@ -357,7 +357,7 @@ setup (GError **err)
     g_signal_connect (bus, "message::error", G_CALLBACK (cb_error), NULL);
     g_signal_connect (bus, "message::state-changed", G_CALLBACK (cb_state), NULL);
 
-    cdp = gst_element_factory_make (CD_SRC, "cd-source");
+    cdp = gst_element_make_from_uri (GST_URI_SRC, "cdda://1", "cd-source");
     if (!cdp) {
       gst_object_unref (GST_OBJECT (pipeline));
       pipeline = NULL;
@@ -367,8 +367,12 @@ setup (GError **err)
     /* do not set to 1, that messes up buffering. 2 is enough to keep
      * noise from the drive down. */
     /* TODO: will not notice drive changes, should monitor */
+    if (g_object_class_find_property (G_OBJECT_GET_CLASS (cdp), "read-speed") != NULL) {
+    	g_object_set (G_OBJECT (cdp),
+    	              "read-speed", 2,
+                      NULL);
+    }
     g_object_set (G_OBJECT (cdp),
-                  "read-speed", 2,
                   "device", nautilus_burn_drive_get_device (drive),
                   NULL);
 
@@ -382,7 +386,15 @@ setup (GError **err)
     resample = gst_element_factory_make ("audioresample", "resample"); g_assert (resample);
     volume = gst_element_factory_make ("volume", "vol"); g_assert (volume);
     g_object_set (G_OBJECT (volume), "volume", vol, NULL);
-    out = gst_element_factory_make ("gconfaudiosink", "out"); g_assert (out);
+    out = gst_element_factory_make ("gconfaudiosink", "out");
+    if (!out) {
+        /* fall back to autoaudiosink */
+        out = gst_element_factory_make ("autoaudiosink", "out");
+    }
+    if (out) {
+        if (g_object_class_find_property (G_OBJECT_GET_CLASS (out), "profile"))
+	    g_object_set (G_OBJECT (out), "profile", 1, NULL);
+    }
 
     gst_bin_add_many (GST_BIN (pipeline), cdp, queue, conv, resample, volume, out, NULL);
     if (!gst_element_link_many (cdp, queue, conv, resample, volume, out, NULL))
